Extract data from Seurat object
Usage
extractFromSeurat(
seurat_obj,
features = NULL,
assay_name = "RNA",
slot_name = "counts",
indiv_colname = "indiv",
...
)Arguments
- seurat_obj
a Seurat object
- features
string vector to filter for features
- assay_name
string scalar to specify the name of input assay data
- slot_name
string scalar to specify the type of input assay data
- indiv_colname
string scalar to specify the column that has the indiv ids
- ...
other options to specify extracted outputs. Currently available:
col_class: logical valuefeat_names: logical valuecell_names: logical valuesc_indiv: logical valueexpr_mat: logical valuesc_cov: logical valuefeat_cov: logical value
Value
a list of extracted data with following optional outputs:
col_class: a vector of the column classes for cell covariate variablesfeat_names: a vector of feature namescell_names: a vector of cell namessc_indiv: a vector of distinct sample ids extracted from cell covariate usingindiv_colnameexpr_mat: an expression matrix extracted usingassay_nameandslot_nameoptionssc_cov: a dataframe for cell covariatesfeat_cov: a dataframe for feature covariates